==> squid-3.1.0.1.tar.bz2: squid-3.1.0.1/src/tests/stub_store_swapout.cc <==
/*
 * $Id: stub_store_swapout.cc,v 1.3 2007/04/17 23:05:20 wessels Exp $
 *
 * DEBUG: section 84    Helper process maintenance
 * AUTHOR: Robert Collins
 *
 * SQUID Web Proxy Cache          http://www.squid-cache.org/
 * ----------------------------------------------------------
 *
 *  Squid is the result of efforts by numerous individuals from
 *  the Internet community; see the CONTRIBUTORS file for full
 *  details.   Many organizations have provided support for Squid's
 *  development; see the SPONSORS file for full details.  Squid is
 *  Copyrighted (C) 2001 by the Regents of the University of
 *  California; see the COPYRIGHT file for full details.  Squid
 *  incorporates software developed and/or copyrighted by other
 *  sources; see the CREDITS file for full details.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 */

#include "squid.h"
#include "Store.h"

void
StoreEntry::swapOutFileClose()
{
    fatal ("Not implemented");
}

bool
StoreEntry::swapOutAble() const
{
    fatal ("Not implemented");
    return false;
}

void
StoreEntry::swapOut()
{
    fatal ("Not implemented");
}

/* wrong stub file... */
void
storeUnlink(StoreEntry * e)
{
    fatal ("Not implemented");
}


void
storeIOStats(StoreEntry *)
{
    fatal ("Not implemented");
}


#include "StoreMeta.h"

char *
storeSwapMetaPack(tlv * tlv_list, int *length)
{
    fatal ("Not implemented");
    return NULL;
}

tlv *
storeSwapMetaBuild(StoreEntry * e)
{
    fatal ("Not implemented");
    return NULL;
}

void
storeSwapTLVFree(tlv * n)
{
    fatal ("Not implemented");
}

==> squid-3.2.5.tar.bz2: squid-3.2.5/src/tests/stub_store_swapout.cc <==
/*
 * $Id$
 *
 * DEBUG: section 84    Helper process maintenance
 * AUTHOR: Robert Collins
 *
 * SQUID Web Proxy Cache          http://www.squid-cache.org/
 * ----------------------------------------------------------
 *
 *  Squid is the result of efforts by numerous individuals from
 *  the Internet community; see the CONTRIBUTORS file for full
 *  details.   Many organizations have provided support for Squid's
 *  development; see the SPONSORS file for full details.  Squid is
 *  Copyrighted (C) 2001 by the Regents of the University of
 *  California; see the COPYRIGHT file for full details.  Squid
 *  incorporates software developed and/or copyrighted by other
 *  sources; see the CREDITS file for full details.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 */

#include "squid.h"
#include "fatal.h"

#if 0
/* wrong stub file... */
void
storeUnlink(StoreEntry * e)
{
    fatal ("Not implemented");
}
#endif

#include "StoreMeta.h"

char *
storeSwapMetaPack(tlv * tlv_list, int *length)
{
    fatal ("Not implemented");
    return NULL;
}

tlv *
storeSwapMetaBuild(StoreEntry * e)
{
    fatal ("Not implemented");
    return NULL;
}

void
storeSwapTLVFree(tlv * n)
{
    fatal ("Not implemented");
}
